# botbuilder-adapter-vonage

This package contains an adapter that communicates directly with the Vonage Messageing API, and translates messages to and from a standard format used by your bot. This package can be used alongside your favorite bot development framework to build bots that work with Vonage Messaging API.

## Node.js Module

This is a npm module in TypeScript, which is "importable" in JavaScript and TypeScript

## History:


- `npm install botkit`
- `npm install @vonage/server-sdk@beta`
- `npm i @types/debug -D`
- `npm i --save-dev @types/debug`

## Install Package


Most npm modules come without a Type definition, so TypeScript developers will have to run an additional `npm i @types/<module_name> -D` command to be able to use the npm module

Add this package to your project using npm:

```bash
npm install --save botbuilder-adapter-vonage
```

Import the adapter class into your code:

```javascript
const { VonageAdapter } = require("botbuilder-adapter-vonage");
```

## Get Started

If you are starting a brand new project, [follow these instructions to create a customized application template.](https://botkit.ai/getstarted.html)

## Use VonageAdapter in your App

VonageAdapter provides a translation layer for Botkit and BotBuilder so that bot developers can connect to Vonage Messaging API.

### Botkit Basics

When used in concert with Botkit, developers need only pass the configured adapter to the Botkit constructor, as seen below. Botkit will automatically create and configure the webhook endpoints and other options necessary for communicating with Google.

Developers can then bind to Botkit's event emitting system using `controller.on` and `controller.hears` to filter and handle incoming events from the messaging platform. [Learn more about Botkit's core feature &rarr;](../docs/index.md).

[A full description of the VonageAdapter options and example code can be found in the class reference docs.](../docs/reference/hangouts.md#create-a-new-VonageAdapter)

```javascript
const adapter = new VonageAdapter({
  to_number: process.env.TO_NUMBER,
  from_number: process.env.FROM_NUMBER,
  apiKey: process.env.API_KEY,
  apiSecret: process.env.API_SECRET,
  applicationId: process.env.APP_ID,
  privateKey: process.env.PRIVATE_KEY_PATH,
});

const controller = new Botkit({
  adapter,
  // ...other options
});

controller.on("message", async (bot, message) => {
  await bot.reply(message, "I heard a message!");
});
```

### BotBuilder Basics

Alternately, developers may choose to use `VonageAdapter` with BotBuilder. With BotBuilder, the adapter is used more directly with a webserver, and all incoming events are handled as [Activities](https://docs.microsoft.com/en-us/javascript/api/botframework-schema/activity?view=botbuilder-ts-latest).

```javascript
const adapter = new VonageAdapter({
  to_number: process.env.TO_NUMBER,
  from_number: process.env.FROM_NUMBER,
  apiKey: process.env.API_KEY,
  apiSecret: process.env.API_SECRET,
  applicationId: process.env.APP_ID,
  privateKey: process.env.PRIVATE_KEY_PATH,
});

const server = restify.createServer();
server.use(restify.plugins.bodyParser());
server.post("/api/messages", (req, res) => {
  adapter.processActivity(req, res, async (context) => {
    await context.sendActivity("I heard a message!");
  });
});
```

## Class Reference

- [VonageAdapter](../docs/reference/vonage.md#VonageAdapter)
- [BotWorker Extensions](../docs/reference/vonage.md#vonagebotworker)

## Calling Vonage Message APIs

This package exposes a pre-configured [Vonage Server API client](https://github.com/Vonage/vonage-node-sdk) for developers who want to use one of the many available API endpoints.

In Botkit handlers, the `bot` worker object passed into all handlers will contain a `bot.api` field that contains the client, preconfigured and ready to use.

```javascript
controller.on('message', async(bot, message) {

    // create a message using the API directly
    let res = await bot.api.channel.send(my_message_object)

});
```

## Botkit Extensions

In Botkit handlers, the `bot` worker for Vonage contains [all of the base methods](../docs/reference/core.md#BotWorker) as well as the following platform-specific extensions:

### Use attachments, quick replies and other rich message features

Botkit will automatically construct your outgoing messages according to Vonage's specifications. To use attachments, quick replies or other features, add them to the message object used to create the reply:

### [bot.startConversationWithUser()](../docs/reference/facebook.md#startconversationwithuser)

Use this method to initiate a conversation with a user. After calling this method, any further actions carried out by the bot worker will happen with the specified user.

This can be used to create or resume conversations with users that are not in direct response to an incoming message, like those sent on a schedule or in response to external events.

## Community & Support

Join our thriving community of Botkit developers and bot enthusiasts at large.
Over 10,000 members strong, [our open Slack group](https://community.botkit.ai) is
_the place_ for people interested in the art and science of making bots.
Come to ask questions, share your progress, and commune with your peers!

You can also find help from members of the Botkit team [in our dedicated Cisco Spark room](https://eurl.io/#SyNZuomKx)!

## About Botkit

Botkit is a part of the [Microsoft Bot Framework](https://dev.botframework.com).

Want to contribute? [Read the contributor guide](https://github.com/howdyai/botkit/blob/master/CONTRIBUTING.md)

Botkit is released under the [MIT Open Source license](https://github.com/howdyai/botkit/blob/master/LICENSE.md)
